@@ -1,7 +1,7 @@
 use strict;
 use warnings FATAL => 'all';
 
-use Test::More tests => 26;
+use Test::More tests => 27;
 
 use List::Util qw(sum);
 use File::Temp qw(tempfile tempdir);
@@ -291,6 +291,24 @@ SKIP: {
 	ok($@ =~ /^FH is closed/,'close()');
 }
 
+{
+  # nested ifs
+  my $ssi = CGI::SSI->new();
+  my $html = $ssi->process(<<"");
+    <!--#if expr="0" -->
+      <!--#if expr="1" -->
+        yes
+      <!--#else -->
+        no
+      <!--#endif -->
+      no
+    <!--#else -->
+      yes
+    <!--#endif -->
+
+  ok($html =~ /^\s*yes\s*$/s,'nested ifs');
+}
+
 # autotie ?
 
 
